@@ -11,6 +11,7 @@ import sys
 from .xml_parser import XmlParser
 from .exceptions import NotChecked
 from ._builder_html_graph import BuilderHtmlGraph
+from .__init__ import __version__
 
 
 class Client():
@@ -38,7 +39,6 @@ class Client():
     def _get_message(self):
         MESSAGES = {
             'description': '',
-            '--output': '',
             'source_filename': '',
         }
         return MESSAGES
@@ -197,10 +197,42 @@ class Client():
         self.prepare_parser()
         return self.parser.parse_args(args)
 
+    def prepare_args_when_output_is_html(self):
+        self.parser.add_argument(
+            '-i',
+            '--all-in-one',
+            action="store_true",
+            default=False,
+            help="Processes all rules into one file.")
+        self.parser.add_argument(
+            '-d',
+            '--display',
+            action="store_true",
+            default=False,
+            help="Enables opening a web browser with a graph, when is used --output.")
+
+    def prepare_args_when_user_can_list_in_rules(self):
+        self.parser.add_argument(
+            '--show-failed-rules',
+            action="store_true",
+            default=False,
+            help="Show only FAILED rules")
+        self.parser.add_argument(
+            '--show-not-selected-rules',
+            action="store_true",
+            default=False,
+            help="Show notselected rules. These rules will not be visualized.")
+
     def prepare_parser(self):
         self.parser = argparse.ArgumentParser(
+            prog='oval-graph',
             description=self.MESSAGES.get('description'))
         self.parser.add_argument(
+            '--version',
+            action='version',
+            version='%(prog)s ' + __version__)
+        self.parser.add_argument(
+            '-a',
             '--all',
             action="store_true",
             default=False,
@@ -211,8 +243,9 @@ class Client():
             default=False,
             help=(
                 "Do not display passing tests for better orientation in"
-                " graphs that contain a large amount of nodes.(Not implemented)"))
+                " graphs that contain a large amount of nodes."))
         self.parser.add_argument(
+            '-v',
             '--verbose',
             action="store_true",
             default=False,
@@ -222,7 +255,7 @@ class Client():
             '--output',
             action="store",
             default=None,
-            help=self.MESSAGES.get('--output'))
+            help='The file where to save output.')
         self.parser.add_argument(
             "source_filename",
             help=self.MESSAGES.get('source_filename'))
